@@ -14,15 +14,13 @@ from cubicweb.devtools.testlib import CubicWebTC
 
 
 class AcceptanceTC(CubicWebTC):
-
     def test_demo_conference_scenario(self):
-        self.assertDocTestFile(join(dirname(__file__), 'demo_conference.txt'))
+        self.assertDocTestFile(join(dirname(__file__), "demo_conference.txt"))
 
     def test_review_process(self):
-        self.skipTest('error in review-process.txt')
-        self.assertDocTestFile(join(dirname(__file__), 'review-process.txt'))
+        self.skipTest("error in review-process.txt")
+        self.assertDocTestFile(join(dirname(__file__), "review-process.txt"))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest_main()
-
